@@ -7,7 +7,7 @@ require "gtk2"
 miquire :mui,
 'cell_renderer_message', 'coordinate_module', 'icon_over_button', 'inner_tl', 'markup_generator',
 'miracle_painter', 'replyviewer', 'sub_parts_favorite', 'sub_parts_helper',
-'sub_parts_retweet', 'sub_parts_voter', 'textselector', 'timeline', 'contextmenu', 'crud',
+'sub_parts_share', 'sub_parts_voter', 'textselector', 'timeline', 'contextmenu', 'crud',
 'extension', 'intelligent_textview', 'keyconfig', 'listlist', 'message_picker', 'mtk', 'postbox',
 'pseudo_signal_handler', 'selectbox', 'timeline_utils', 'userlist', 'webicon'
 
@@ -351,10 +351,9 @@ Plugin.create :gtk do
     end
   end
 
-  on_gui_postbox_post do |i_postbox|
-    postbox = widgetof(i_postbox)
-    if postbox
-      postbox.post_it end end
+  on_gui_postbox_post do |i_postbox, options|
+    widgetof(i_postbox)&.post_it(world: options[:world])
+  end
 
   # i_widget.destroyされた時に呼ばれる。
   # 必要ならば、ウィジェットの実体もあわせて削除する。
@@ -492,6 +491,14 @@ Plugin.create :gtk do
     Plugin::Gtk::DialogWindow.open(plugin: plugin, title: title, default: default, promise: promise, &proc)
   end
 
+  filter_before_mainloop_exit do
+    if !@slug_dictionary.widgets(Plugin::GUI::Window).all?(&:destroyed?)
+      error "Filter before_mainloop_exit was canceled because window already exists."
+      Plugin.filter_cancel!
+    end
+    []
+  end
+
   # タブ _tab_ に _widget_ を入れる
   # ==== Args
   # [i_tab] タブ
@@ -565,20 +572,24 @@ Plugin.create :gtk do
   # ウィンドウ内のペイン、タブの現在の順序を設定に保存する
   on_rewind_window_order do |i_window|
     if :default == i_window.slug
-      panes_order = {}
-      i_window.children.each{ |i_pane|
-        if i_pane.is_a? Plugin::GUI::Pane
-          tab_order = []
+      panes_order = Hash[
+        i_window.children.select{|i_pane|
+          i_pane.is_a?(Plugin::GUI::Pane)
+        }.map{|i_pane|
           pane = widgetof(i_pane)
-          if pane
-            pane.n_pages.times{ |page_num|
-              i_widget = find_implement_widget_by_gtkwidget(pane.get_tab_label(pane.get_nth_page(page_num)))
-              if i_widget and not i_widget.temporary_tab? and i_widget.children.any?{ |child| not child.is_a? Plugin::GUI::TabToolbar }
-                tab_order << i_widget.slug end } end
-          panes_order[i_pane.slug] = tab_order if not tab_order.empty? end }
+          tab_order = pane.n_pages.times.map{ |page_num|
+            find_implement_widget_by_gtkwidget(pane.get_tab_label(pane.get_nth_page(page_num)))
+          }.select{|i_widget|
+            i_widget && !i_widget.temporary_tab? && i_widget.children.any?{ |child| !child.is_a? Plugin::GUI::TabToolbar }
+          }.map(&:slug)
+          [i_pane.slug, tab_order] if not tab_order.empty?
+        }.compact
+      ]
       ui_tab_order = (UserConfig[:ui_tab_order] || {}).melt
       ui_tab_order[i_window.slug] = panes_order
-      UserConfig[:ui_tab_order] = ui_tab_order end end
+      UserConfig[:ui_tab_order] = ui_tab_order
+    end
+  end
 
   # ペインを順序リストから削除する
   # ==== Args
@@ -611,6 +622,26 @@ Plugin.create :gtk do
   # _widget_ に対応するウィジェットオブジェクトまたは偽
   def find_implement_widget_by_gtkwidget(widget)
     @slug_dictionary.imaginally_by_gtk(widget) end
+
+  # timeline_maxを取得するフィルタ
+  filter_gui_timeline_get_timeline_max do |i_tl, _|
+    [i_tl, widgetof(i_tl).timeline_max]
+  end
+
+  # timeline_maxを設定するフィルタ
+  filter_gui_timeline_set_timeline_max do |i_tl, n|
+    widgetof(i_tl).timeline_max = n
+    [i_tl, n]
+  end
+
+  # タイムラインのメッセージを順に処理するフィルタ
+  filter_gui_timeline_each_messages do |i_tl, y|
+    widgetof(i_tl).each do |m|
+      y << m
+    end
+    [i_tl, y]
+  end
+
 end
 
 module Plugin::Gtk
