@@ -234,13 +234,13 @@ class Plugin::Twitter::Message < Diva::Model
   # _other_ は、 User か_other_[:id]と_other_[:idname]が呼び出し可能なもの。
   def receive_to?(other)
     type_strict other => :[]
-    (self[:receiver] and other[:id] == self[:receiver].id) or receive_user_screen_names.include? other[:idname] end
+    (self[:receiver] and other[:id] == self[:receiver].id) or receive_user_idnames.include? other[:idname] end
 
   # このツイートが宛てられたユーザを可能な限り推測して、その idname(screen_name) を配列で返す。
   # 例えばツイート本文内に「@a @b @c」などと書かれていたら、["a", "b", "c"]を返す。
   # ==== Return
   # 宛てられたユーザの idname(screen_name) の配列
-  def receive_user_screen_names
+  def receive_user_idnames
     self[:message].to_s.scan(MentionMatcher).map(&:first) end
 
   # 自分がこのMessageにリプライを返していればtrue
@@ -636,7 +636,10 @@ class Plugin::Twitter::Message < Diva::Model
   def body
     self[:message].to_s.freeze
   end
-  alias_method :description, :body
+
+  def description
+    self[:message].to_s.gsub(Plugin::Twitter::Message::DESCRIPTION_UNESCAPE_REGEXP, &Plugin::Twitter::Message::DESCRIPTION_UNESCAPE_RULE)
+  end
 
   # Message#body と同じだが、投稿制限文字数を超えていた場合には、収まるように末尾を捨てる。
   def to_s
@@ -744,6 +747,10 @@ class Plugin::Twitter::Message < Diva::Model
     self end
 
   class DataSource < Diva::Model::Memory
+    def initialize
+      super(Plugin::Twitter::Message)
+    end
+
     def findbyid(id, policy)
       if id.is_a? Enumerable
         super.map do |v|
